Package: widgetTools
Title: Creates an interactive tcltk widget
Version: 1.89.0
Date: 2008-10-28
Author: Jianhua Zhang
Description: This packages contains tools to support the construction
        of tcltk widgets
Depends: R (>= 2.4.0), methods, utils, tcltk
Suggests: Biobase
biocViews: Infrastructure
LazyLoad: yes
Maintainer: Jianhua Zhang <jzhang@jimmy.harvard.edu>
License: LGPL
git_url: https://git.bioconductor.org/packages/widgetTools
git_branch: devel
git_last_commit: 0513252
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 23:36:50 UTC; biocbuild
